@@ -2,6 +2,9 @@
 Django admin declarations
 """
 
+# Third Party
+from solo.admin import SingletonModelAdmin
+
 # Django
 from django.contrib import admin, messages
 from django.utils.translation import gettext_lazy as _
@@ -64,58 +67,6 @@ def custom_filter(title):
     return Wrapper
 
 
-class SingletonModelAdmin(admin.ModelAdmin):
-    """
-    Prevents Django admin users deleting the singleton or adding extra rows.
-    """
-
-    actions = None  # Removes the default delete action.
-
-    def has_add_permission(self, request):  # pylint: disable=unused-argument
-        """
-        Has "add" permissions
-
-        :param request:
-        :type request:
-        :return:
-        :rtype:
-        """
-
-        return self.model.objects.all().count() == 0
-
-    def has_change_permission(
-        self, request, obj=None  # pylint: disable=unused-argument
-    ):
-        """
-        Has "change" permissions
-
-        :param request:
-        :type request:
-        :param obj:
-        :type obj:
-        :return:
-        :rtype:
-        """
-
-        return True
-
-    def has_delete_permission(
-        self, request, obj=None  # pylint: disable=unused-argument
-    ):
-        """
-        Has "delete" permissions
-
-        :param request:
-        :type request:
-        :param obj:
-        :type obj:
-        :return:
-        :rtype:
-        """
-
-        return False
-
-
 @admin.register(SrpLink)
 class SrpLinkAdmin(admin.ModelAdmin):
     """
@@ -226,7 +177,7 @@ class FleetTypeAdmin(admin.ModelAdmin):
     list_filter = ("is_enabled",)
     ordering = ("name",)
 
-    @admin.display(description=_("Fleet Type"), ordering="name")
+    @admin.display(description=_("Fleet type"), ordering="name")
     def _name(self, obj):
         """
         Rewrite name
