@@ -4,6 +4,16 @@ App settings
 
 # Django
 from django.apps import apps
+from django.conf import settings
+
+# Port used to communicate with Discord Proxy
+DISCORDPROXY_PORT = getattr(settings, "DISCORDPROXY_PORT", 50051)
+
+# Host used to communicate with Discord Proxy
+DISCORDPROXY_HOST = getattr(settings, "DISCORDPROXY_HOST", "localhost")
+
+# Timeout for Discord Proxy communication
+DISCORDPROXY_TIMEOUT = getattr(settings, "DISCORDPROXY_TIMEOUT", 300)
 
 
 def allianceauth_discordbot_installed() -> bool:
