@@ -19,7 +19,7 @@ from app_utils.logging import LoggerAddTag
 
 # AA SRP
 from aasrp import __title__
-from aasrp.constants import USERAGENT, ZKILLBOARD_API_URL
+from aasrp.constants import KILLBOARD_DATA, USERAGENT
 from aasrp.providers import esi
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
@@ -47,7 +47,7 @@ class SrpManager:
         return kill_id
 
     @staticmethod
-    def get_kill_data(kill_id: str):
+    def get_kill_data(kill_id: str):  # pylint: disable=too-many-locals
         """
         Get kill data from zKillboard
 
@@ -57,7 +57,8 @@ class SrpManager:
         :rtype:
         """
 
-        url = f"{ZKILLBOARD_API_URL}killID/{kill_id}/"
+        zkillboard_api_url = KILLBOARD_DATA["zKillboard"]["api_url"]
+        url = f"{zkillboard_api_url}killID/{kill_id}/"
         headers = {"User-Agent": USERAGENT, "Content-Type": "application/json"}
         request_result = requests.get(url=url, headers=headers, timeout=5)
 
@@ -67,7 +68,7 @@ class SrpManager:
             error_str = str(exc)
 
             logger.warning(
-                msg=f"Unable to get killmail details from zKillboard. Error: {error_str}",
+                msg=f"Unable to get kill mail details from zKillboard. Error: {error_str}",
                 exc_info=True,
             )
 
@@ -79,7 +80,25 @@ class SrpManager:
 
             raise ValueError(error_str) from exc
 
-        result = request_result.json()[0]
+        result_killmails = request_result.json()
+        result = None
+        for killmail in result_killmails:
+            if killmail["killmail_id"] == int(kill_id):
+                result = killmail
+
+        if not result:
+            logger.warning(
+                msg=(
+                    "Couldn't find any kill mail information in zKillboard's API response. "
+                    "This is likely an issue with zKillboard."
+                ),
+                exc_info=True,
+            )
+
+            raise ValueError(
+                "Couldn't find any kill mail information in zKillboard's API response. "
+                "This is likely an issue with zKillboard."
+            )
 
         try:
             killmail_id = result["killmail_id"]
@@ -91,8 +110,13 @@ class SrpManager:
         except Exception as exc:
             raise ValueError("Invalid Kill ID or Hash.") from exc
 
+        # AA SRP
+        from aasrp.models import Setting  # pylint: disable=import-outside-toplevel
+
+        loss_value_field = Setting.objects.get_setting(Setting.Field.LOSS_VALUE_SOURCE)
+
         ship_type = esi_killmail["victim"]["ship_type_id"]
-        ship_value = result["zkb"]["totalValue"]
+        ship_value = result["zkb"][loss_value_field]
 
         logger.debug(msg=f"Ship type for kill ID {kill_id} is {ship_type}")
         logger.debug(msg=f"Total loss value for kill id {kill_id} is {ship_value}")
