@@ -12,6 +12,7 @@ from django.utils.translation import gettext_lazy as _
 
 # Alliance Auth
 from allianceauth.authentication.decorators import permissions_required
+from allianceauth.framework.api.user import get_main_character_name_from_user
 from allianceauth.services.hooks import get_extension_logger
 
 # Alliance Auth (External Libs)
@@ -29,10 +30,7 @@ from aasrp.form import (
     SrpRequestPayoutForm,
     SrpRequestRejectForm,
 )
-from aasrp.helper.character import (
-    get_formatted_character_name,
-    get_main_character_from_user,
-)
+from aasrp.helper.character import get_formatted_character_name
 from aasrp.helper.eve_images import get_type_render_url_from_type_id
 from aasrp.helper.icons import (
     get_dashboard_action_icons,
@@ -117,16 +115,15 @@ def dashboard_srp_links_data(
 
         srp_code_html = srp_link.srp_code
         if srp_link.srp_status == SrpLink.Status.ACTIVE:
-            css_classes = (
-                "aa-srp-fa-icon aa-srp-fa-icon-right copy-text-fa-icon far fa-copy"
-            )
+            css_classes = "aa-srp-fa-icon copy-text-fa-icon fa-regular fa-copy ms-2"
             srp_link_href = reverse_absolute(
                 viewname="aasrp:request_srp", args=[srp_link.srp_code]
             )
             title = _("Copy SRP link to clipboard")
             srp_code_html += (
                 f'<i class="{css_classes}" '
-                f'data-clipboard-text="{srp_link_href}" title="{title}"></i>'
+                f'data-clipboard-text="{srp_link_href}" title="{title}" '
+                'data-bs-tooltip="aa-srp"></i>'
             )
 
         actions = get_dashboard_action_icons(request=request, srp_link=srp_link)
@@ -138,10 +135,10 @@ def dashboard_srp_links_data(
         data.append(
             {
                 "srp_name": srp_link.srp_name,
-                "creator": get_main_character_from_user(user=srp_link.creator),
+                "creator": get_main_character_name_from_user(user=srp_link.creator),
                 "fleet_time": srp_link.fleet_time,
                 "fleet_type": fleet_type,
-                "fleet_commander": srp_link.fleet_commander.character_name,
+                # "fleet_commander": srp_link.fleet_commander.character_name,
                 "fleet_doctrine": srp_link.fleet_doctrine,
                 "aar_link": aar_link,
                 "srp_code": {"display": srp_code_html, "sort": srp_link.srp_code},
@@ -252,7 +249,7 @@ def dashboard_user_srp_requests_data(request: WSGIRequest) -> JsonResponse:
                 "request_status_icon": (
                     srp_request_details_icon + srp_request_status_icon
                 ),
-                "request_status": srp_request.request_status,
+                "request_status": srp_request.get_request_status_display(),
             }
         )
 
@@ -329,7 +326,7 @@ def srp_link_view_requests_data(request: WSGIRequest, srp_code: str) -> JsonResp
         data.append(
             {
                 "request_time": srp_request.post_time,
-                "requester": get_main_character_from_user(srp_request.creator),
+                "requester": get_main_character_name_from_user(srp_request.creator),
                 "character_html": {
                     "display": character_display,
                     "sort": character_sort,
@@ -344,6 +341,7 @@ def srp_link_view_requests_data(request: WSGIRequest, srp_code: str) -> JsonResp
                 "payout_amount": srp_request.payout_amount,
                 "request_status_icon": srp_request_status_icon,
                 "actions": srp_request_action_icons,
+                "request_status_translated": srp_request.get_request_status_display(),
                 "request_status": srp_request.request_status,
             }
         )
@@ -412,7 +410,7 @@ def srp_request_additional_information(
             srp_request=srp_request, comment_type=RequestComment.Type.REQUEST_INFO
         )
 
-        additional_info = additional_info_comment.comment.replace("\n", "<br>\n")
+        additional_info = additional_info_comment.comment
     except RequestComment.DoesNotExist:
         additional_info = ""
 
@@ -428,18 +426,18 @@ def srp_request_additional_information(
         "srp_request": srp_request,
         "ship_render_icon_html": ship_render_icon_html,
         "ship_type": srp_request.ship.name,
-        "requester": get_main_character_from_user(user=srp_request.creator),
+        "requester": get_main_character_name_from_user(user=srp_request.creator),
         "character": character,
         "additional_info": additional_info,
         "request_status_banner_alert_level": request_status_banner_alert_level,
-        "request_status": srp_request.request_status,
+        "request_status": srp_request.get_request_status_display(),
         "insurance_information": insurance_information,
         "request_history": request_history,
     }
 
     return render(
         request=request,
-        template_name="aasrp/ajax_render/srp_request_additional_information.html",
+        template_name="aasrp/ajax-render/srp-request-additional-information.html",
         context=data,
     )
 
@@ -529,7 +527,7 @@ def srp_request_approve(  # pylint: disable=too-many-locals
                 srp_isk_loss = srp_request.loss_amount
 
                 # Reviser comment
-                reviser_comment = form.cleaned_data["reviser_comment"]
+                reviser_comment = form.cleaned_data["comment"]
 
                 if srp_payout == 0:
                     srp_request.payout_amount = srp_isk_loss
@@ -562,7 +560,7 @@ def srp_request_approve(  # pylint: disable=too-many-locals
                     fleet_name = srp_request.srp_link.srp_name
                     srp_code = srp_request.srp_link.srp_code
                     request_code = srp_request.request_code
-                    reviser = get_main_character_from_user(user=request.user)
+                    reviser = get_main_character_name_from_user(user=request.user)
                     reviser_comment = (
                         f"\nComment:\n{reviser_comment}\n"
                         if reviser_comment != ""
@@ -626,7 +624,7 @@ def srp_request_deny(
 
             # Check whether it's valid:
             if form.is_valid():
-                reject_info = form.cleaned_data["reject_info"]
+                reject_info = form.cleaned_data["comment"]
                 requester = srp_request.creator
 
                 srp_request.payout_amount = 0
@@ -657,7 +655,7 @@ def srp_request_deny(
                     fleet_name = srp_request.srp_link.srp_name
                     srp_code = srp_request.srp_link.srp_code
                     request_code = srp_request.request_code
-                    reviser = get_main_character_from_user(user=request.user)
+                    reviser = get_main_character_name_from_user(user=request.user)
                     inquiry_note = SRP_REQUEST_NOTIFICATION_INQUIRY_NOTE
                     notification_message = (
                         f"Your SRP request regarding your {ship_name} lost during "
@@ -673,7 +671,7 @@ def srp_request_deny(
                     send_user_notification(
                         user=requester,
                         level="danger",
-                        title=_("SRP Request Rejected"),
+                        title=_("SRP request rejected"),
                         message=notification_message,
                     )
 
