@@ -23,7 +23,7 @@ from eveuniverse.models import EveType
 
 # AA SRP
 from aasrp import __title__
-from aasrp.constants import EVETOOLS_KILLBOARD_BASE_URL, ZKILLBOARD_BASE_URL
+from aasrp.constants import KILLBOARD_DATA
 from aasrp.form import (
     SrpLinkForm,
     SrpLinkUpdateForm,
@@ -38,12 +38,12 @@ from aasrp.helper.user import get_user_settings
 from aasrp.managers import SrpManager
 from aasrp.models import Insurance, RequestComment, SrpLink, SrpRequest
 
-logger = LoggerAddTag(get_extension_logger(__name__), __title__)
+logger = LoggerAddTag(my_logger=get_extension_logger(__name__), prefix=__title__)
 
 
 @login_required
 @permission_required("aasrp.basic_access")
-def dashboard(request: WSGIRequest, show_all_links: bool = False) -> HttpResponse:
+def srp_links(request: WSGIRequest, show_all_links: bool = False) -> HttpResponse:
     """
     SRP dashboard
 
@@ -55,25 +55,6 @@ def dashboard(request: WSGIRequest, show_all_links: bool = False) -> HttpRespons
     :rtype:
     """
 
-    user_settings = get_user_settings(user=request.user)
-
-    # If this is a POST request, we need to process the form data
-    if request.method == "POST":
-        user_settings_form = UserSettingsForm(data=request.POST, instance=user_settings)
-
-        # Check whether it's valid:
-        if user_settings_form.is_valid():
-            user_settings.disable_notifications = user_settings_form.cleaned_data[
-                "disable_notifications"
-            ]
-            user_settings.save()
-
-            messages.success(request=request, message=_("Settings saved."))
-
-            return redirect(to="aasrp:dashboard")
-    else:
-        user_settings_form = UserSettingsForm(instance=user_settings)
-
     logger_message = f"Dashboard with available SRP links called by {request.user}"
 
     if show_all_links is True:
@@ -85,22 +66,78 @@ def dashboard(request: WSGIRequest, show_all_links: bool = False) -> HttpRespons
                 ),
             )
 
-            return redirect(to="aasrp:dashboard")
+            return redirect(to="aasrp:srp_links")
 
         logger_message = f"Dashboard with all SRP links called by {request.user}"
 
     logger.info(msg=logger_message)
 
-    context = {
-        "show_all_links": show_all_links,
-        "user_settings_form": user_settings_form,
-    }
+    context = {"show_all_links": show_all_links}
 
     return render(
         request=request, template_name="aasrp/dashboard.html", context=context
     )
 
 
+@login_required
+@permission_required("aasrp.basic_access")
+def view_own_requests(request: WSGIRequest) -> HttpResponse:
+    """
+    View own SRP requests
+
+    :param request:
+    :type request:
+    :return:
+    :rtype:
+    """
+
+    logger.info(msg=f"Own SRP requests view called by {request.user}")
+
+    return render(request=request, template_name="aasrp/view-own-requests.html")
+
+
+@login_required
+@permission_required("aasrp.basic_access")
+def user_settings(request: WSGIRequest) -> HttpResponse:
+    """
+    User settings
+
+    :param request:
+    :type request:
+    :return:
+    :rtype:
+    """
+
+    current_user_settings = get_user_settings(user=request.user)
+
+    # If this is a POST request, we need to process the form data.
+    if request.method == "POST":
+        user_settings_form = UserSettingsForm(
+            data=request.POST, instance=current_user_settings
+        )
+
+        # Check whether it's valid:
+        if user_settings_form.is_valid():
+            current_user_settings.disable_notifications = (
+                user_settings_form.cleaned_data["disable_notifications"]
+            )
+            current_user_settings.save()
+
+            messages.success(request=request, message=_("Settings saved."))
+
+            return redirect(to="aasrp:user_settings")
+    else:
+        user_settings_form = UserSettingsForm(instance=current_user_settings)
+
+    logger.info(msg=f"User settings view called by {request.user}")
+
+    context = {"user_settings_form": user_settings_form}
+
+    return render(
+        request=request, template_name="aasrp/user-settings.html", context=context
+    )
+
+
 @login_required
 @permissions_required(("aasrp.manage_srp", "aasrp.create_srp"))
 def srp_link_add(request: WSGIRequest) -> HttpResponse:
@@ -117,9 +154,9 @@ def srp_link_add(request: WSGIRequest) -> HttpResponse:
 
     logger.info(msg=f"Add SRP link form called by {request_user}")
 
-    # If this is a POST request, we need to process the form data
+    # If this is a POST request, we need to process the form data.
     if request.method == "POST":
-        # Create a form instance and populate it with data from the request
+        # Create a form instance and populate it with data from the request.
         form = SrpLinkForm(data=request.POST)
 
         # Check whether it's valid:
@@ -146,15 +183,15 @@ def srp_link_add(request: WSGIRequest) -> HttpResponse:
                 request=request, message=_(f'SRP link "{srp_link.srp_code}" created')
             )
 
-            return redirect(to="aasrp:dashboard")
+            return redirect(to="aasrp:srp_links")
 
-    # If a GET (or any other method) we'll create a blank form
+    # If a GET (or any other method) we'll create a blank form.
     else:
         form = SrpLinkForm()
 
     context = {"form": form}
 
-    return render(request=request, template_name="aasrp/link_add.html", context=context)
+    return render(request=request, template_name="aasrp/link-add.html", context=context)
 
 
 @login_required
@@ -185,11 +222,11 @@ def srp_link_edit(request: WSGIRequest, srp_code: str) -> HttpResponse:
             request=request, message=_(f"Unable to locate SRP code with ID {srp_code}")
         )
 
-        return redirect(to="aasrp:dashboard")
+        return redirect(to="aasrp:srp_links")
 
     srp_link = SrpLink.objects.get(srp_code=srp_code)
 
-    # If this is a POST request, we need to process the form data
+    # If this is a POST request, we need to process the form data.
     if request.method == "POST":
         # Create a form instance and populate it with data
         form = SrpLinkUpdateForm(data=request.POST, instance=srp_link)
@@ -203,18 +240,18 @@ def srp_link_edit(request: WSGIRequest, srp_code: str) -> HttpResponse:
 
             messages.success(request=request, message=_("AAR link changed"))
 
-            return redirect(to="aasrp:dashboard")
+            return redirect(to="aasrp:srp_links")
     else:
         form = SrpLinkUpdateForm(instance=srp_link)
 
     context = {"srp_code": srp_code, "form": form}
 
     return render(
-        request=request, template_name="aasrp/link_edit.html", context=context
+        request=request, template_name="aasrp/link-edit.html", context=context
     )
 
 
-def _save_srp_request(  # pylint: disable=too-many-arguments, too-many-locals
+def _save_srp_request(  # pylint: disable=too-many-arguments, too-many-locals, too-many-positional-arguments
     request: WSGIRequest,
     srp_link: SrpLink,
     killmail_link: str,
@@ -319,7 +356,9 @@ def _save_srp_request(  # pylint: disable=too-many-arguments, too-many-locals
 
 @login_required
 @permission_required("aasrp.basic_access")
-def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
+def request_srp(  # pylint: disable=too-many-locals
+    request: WSGIRequest, srp_code: str
+) -> HttpResponse:
     """
     SRP request
 
@@ -353,7 +392,7 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
             message=_(f"Unable to locate SRP Fleet using SRP code {srp_code}"),
         )
 
-        return redirect("aasrp:dashboard")
+        return redirect("aasrp:srp_links")
 
     # Check if the SRP link is still open
     if srp_link.srp_status != SrpLink.Status.ACTIVE:
@@ -362,11 +401,11 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
             message=_("This SRP link is no longer available for SRP requests."),
         )
 
-        return redirect(to="aasrp:dashboard")
+        return redirect(to="aasrp:srp_links")
 
-    # If this is a POST request, we need to process the form data
+    # If this is a POST request, we need to process the form data.
     if request.method == "POST":
-        # Create a form instance and populate it with data from the request
+        # Create a form instance and populate it with data from the request.
         form = SrpRequestForm(data=request.POST)
         form_is_valid = form.is_valid()
 
@@ -386,7 +425,7 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
                 (ship_type_id, ship_value, victim_id) = SrpManager.get_kill_data(
                     kill_id=srp_kill_link_id
                 )
-            except ValueError:
+            except ValueError as err:
                 # Invalid killmail
                 logger.debug(
                     msg=(
@@ -396,13 +435,21 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
                     )
                 )
 
-                error_message_text = _(
-                    f"Your Killmail link ({submitted_killmail_link}) is invalid or the zKillboard API is not answering at the moment. Please make sure you are using either {ZKILLBOARD_BASE_URL} or {EVETOOLS_KILLBOARD_BASE_URL}"  # pylint: disable=line-too-long
-                )
+                if len(str(err)) > 0:
+                    error_message_text = _(
+                        f"Something went wrong, your kill mail ({submitted_killmail_link}) could not be parsed: {str(err)}"  # pylint: disable=line-too-long
+                    )
+                else:
+                    zkillboard_base_url: str = KILLBOARD_DATA["zKillboard"]["base_url"]
+                    evetools_base_url: str = KILLBOARD_DATA["EveTools"]["base_url"]
+                    eve_kill_base_url: str = KILLBOARD_DATA["EVE-KILL"]["base_url"]
+                    error_message_text = _(
+                        f"Your kill mail link ({submitted_killmail_link}) is invalid or the zKillboard API is not answering at the moment. Please make sure you are using either {zkillboard_base_url}, {evetools_base_url} or {eve_kill_base_url}"  # pylint: disable=line-too-long
+                    )
 
                 messages.error(request=request, message=error_message_text)
 
-                return redirect(to="aasrp:dashboard")
+                return redirect(to="aasrp:srp_links")
 
             if request.user.character_ownerships.filter(
                 character__character_id=str(victim_id)
@@ -418,12 +465,12 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
                     additional_info=srp_request_additional_info,
                 )
 
-                # Send a message to the srp team in their discord channel
+                # Send a message to the srp team in their discord channel.
                 notify_srp_team(
                     srp_request=srp_request, additional_info=srp_request_additional_info
                 )
 
-                return redirect(to="aasrp:dashboard")
+                return redirect(to="aasrp:srp_links")
 
             messages.error(
                 request=request,
@@ -432,9 +479,9 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
                 ),
             )
 
-            return redirect(to="aasrp:dashboard")
+            return redirect(to="aasrp:srp_links")
 
-    # If a GET (or any other method) we'll create a blank form
+    # If a GET (or any other method) we'll create a blank form.
     else:
         logger.debug(msg=f"Returning blank SRP request form for {request.user}")
 
@@ -443,7 +490,7 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
     context = {"srp_link": srp_link, "form": form}
 
     return render(
-        request=request, template_name="aasrp/request_srp.html", context=context
+        request=request, template_name="aasrp/request-srp.html", context=context
     )
 
 
@@ -475,7 +522,7 @@ def complete_srp_link(request: WSGIRequest, srp_code: str):
             request=request, message=_(f"Unable to locate SRP code with ID {srp_code}")
         )
 
-        return redirect(to="aasrp:dashboard")
+        return redirect(to="aasrp:srp_links")
 
     srp_link = SrpLink.objects.get(srp_code=srp_code)
     srp_link.srp_status = SrpLink.Status.COMPLETED
@@ -483,7 +530,7 @@ def complete_srp_link(request: WSGIRequest, srp_code: str):
 
     messages.success(request=request, message=_("SRP link marked as completed"))
 
-    return redirect(to="aasrp:dashboard")
+    return redirect(to="aasrp:srp_links")
 
 
 @login_required
@@ -514,7 +561,7 @@ def srp_link_view_requests(request: WSGIRequest, srp_code: str) -> HttpResponse:
             request=request, message=_(f"Unable to locate SRP code with ID {srp_code}")
         )
 
-        return redirect(to="aasrp:dashboard")
+        return redirect(to="aasrp:srp_links")
 
     srp_link = SrpLink.objects.get(srp_code=srp_code)
     reject_form = SrpRequestRejectForm()
@@ -531,7 +578,7 @@ def srp_link_view_requests(request: WSGIRequest, srp_code: str) -> HttpResponse:
     }
 
     return render(
-        request=request, template_name="aasrp/view_requests.html", context=context
+        request=request, template_name="aasrp/view-requests.html", context=context
     )
 
 
@@ -561,7 +608,7 @@ def enable_srp_link(request: WSGIRequest, srp_code: str):
             request=request, message=_(f"Unable to locate SRP code with ID {srp_code}")
         )
 
-        return redirect(to="aasrp:dashboard")
+        return redirect(to="aasrp:srp_links")
 
     srp_link = SrpLink.objects.get(srp_code=srp_code)
     srp_link.srp_status = SrpLink.Status.ACTIVE
@@ -569,7 +616,7 @@ def enable_srp_link(request: WSGIRequest, srp_code: str):
 
     messages.success(request=request, message=_(f"SRP link {srp_code} (re-)activated."))
 
-    return redirect(to="aasrp:dashboard")
+    return redirect(to="aasrp:srp_links")
 
 
 @login_required
@@ -598,7 +645,7 @@ def disable_srp_link(request: WSGIRequest, srp_code: str):
             request=request, message=_(f"Unable to locate SRP code with ID {srp_code}")
         )
 
-        return redirect(to="aasrp:dashboard")
+        return redirect(to="aasrp:srp_links")
 
     srp_link = SrpLink.objects.get(srp_code=srp_code)
     srp_link.srp_status = SrpLink.Status.CLOSED
@@ -606,7 +653,7 @@ def disable_srp_link(request: WSGIRequest, srp_code: str):
 
     messages.success(request=request, message=_(f"SRP link {srp_code} disabled."))
 
-    return redirect(to="aasrp:dashboard")
+    return redirect(to="aasrp:srp_links")
 
 
 @login_required
@@ -635,11 +682,11 @@ def delete_srp_link(request: WSGIRequest, srp_code: str):
             request=request, message=_(f"Unable to locate SRP code with ID {srp_code}")
         )
 
-        return redirect(to="aasrp:dashboard")
+        return redirect(to="aasrp:srp_links")
 
     srp_link = SrpLink.objects.get(srp_code=srp_code)
     srp_link.delete()
 
     messages.success(request=request, message=_(f"SRP link {srp_code} deleted."))
 
-    return redirect(to="aasrp:dashboard")
+    return redirect(to="aasrp:srp_links")
